<?php
/**
 * This file implements the TOC plugin.
 *
 * @package plugins
 *
 * @author Jeremy Bettis
 *
 */
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * TOC Plugin
 *
 * @package plugins
 */
class toc_plugin extends Plugin
{
	/**
	 * Variables below MUST be overriden by plugin implementations,
	 * either in the subclass declaration or in the subclass constructor.
	 */
	var $name = 'Toc';
	var $code = 'ddbf_TOC';
	var $priority = 75;
	var $version = '1.0';
	var $author = 'Jeremy Bettis';
	var $help_url = 'http://www.deadbeef.com/index.php/b2e_toc';

	/*
	 * These variables MAY be overriden.
	 */
// 1.6
	var $is_tool = false;
	var $apply_when = 'opt-in';
	var $apply_to_html = true;
	var $apply_to_xml = false; // To prevent recursion
// 1.8
	var $apply_rendering = 'opt-in';
	var $number_of_installs = 1;


	/**
	 * Constructor.
	 *
	 * {@internal toc_plugin::toc_plugin(-)}}
	 */
	function toc_plugin()
	{
		$this->short_desc = T_('toc plugin');
		$this->long_desc = T_('This plugin implements a <!--toc--> tag');
	}


	/**
	/**
	 * Event handlers:
	 */

	/**
	 * Event handler: Called when ending the admin html head section.
	 *
	 * {@internal toc_plugin::AdminEndHtmlHead(-)}}
	 *
	 * @param array Associative array of parameters
	 * @return boolean did we do something?
	 */
	function AdminEndHtmlHead( & $params )
	{
		return false;
	}


	/**
	 * Event handler: Called right after displaying the admin page footer.
	 *
	 * {@internal toc_plugin::AdminAfterPageFooter(-)}}
	 *
	 * @param array Associative array of parameters
	 * @return boolean did we do something?
	 */
	function AdminAfterPageFooter( & $params )
	{
		return false;
	}


//1.6
	function Render(& $params )
	{
		if( ! parent::Render( $params ) )
		{ // We cannot render the required format
			return false;
		}
		$parts = Array();
		$params['data'] = preg_replace_callback('/<!-- *toc([^>]*) *-->/',
		create_function('$matches', '
			global $blog;
			global $Plugins;
			$myopts = Array();
			$myopts["category"]="";
			$myopts["num"]=10;
			$myopts["cut"]=10;
			$myopts["dates"]="true";

			$opts = $matches[1];
			$parts = Array();
			while (ereg(\'^ *([a-zA-Z0-9_]*) *="([^"]*)" *(.*)\', $opts, $parts)) {
				$myopts[$parts[1]] = $parts[2];
				$opts = $parts[3];
			}
			
			$mytext = "<ul class=\"toc\">";
			$TOCList = & new ItemList($blog, array(), "", "", -1, $myopts["category"], array(), "", "DESC", "", $myopts["num"]);
			if (isset($TOCList)) while( $TOCItem = $TOCList->get_item() ) {
				$mytext .= "<li>";
				if ($myopts["dates"] == "true" || $myopts["dates"] == "on") {
					$mytext .= mysql2date( locale_datefmt(), $TOCItem->issue_date, false);
					$mytext .= "<br />";
				}
				$mytext .= "<a href=\"";
				$mytext .= $TOCItem->gen_permalink("", "");
				$mytext .= "\">"; 
				$mytext .= $TOCItem->title;
				$mytext .= "</a><br/>";
				$content = $TOCItem->content;
				$content = preg_replace("/<!--nextpage-->(\n|.)*/", "", $content);
				$content = preg_replace("/<!--more-->(\n|.)*/", "", $content);
				$post_renderers = $Plugins->validate_list( $TOCItem->renderers );
				$content = $Plugins->render( $content, $post_renderers, "xml" );
				$content = format_to_output( $content, "xml" );
				$blah = explode(" ", $content);
				if (count($blah) > $myopts["cut"]) {
					$content="";
					for ($i=0; $i<$myopts["cut"]; $i++)
					{
						$content .= $blah[$i]." ";
					}
					$content .= "...";
				}
				$mytext .= $content;
				$mytext .= "</li>";
			}
			$mytext .= "</ul>";
			return $mytext;'
		),
		$params['data']);
		return true;
	}
//1.8
	function RenderItemAsHtml( & $params )
	{
		$parts = Array();
		$params['data'] = preg_replace_callback('/<!-- *toc([^>]*) *-->/',
		create_function('$matches', '
			global $blog;
			global $Plugins;
			$myopts = Array();
			$myopts["category"]="";
			$myopts["num"]=10;
			$myopts["cut"]=10;
			$myopts["dates"]="true";

			$opts = $matches[1];
			$parts = Array();
			while (ereg(\'^ *([a-zA-Z0-9_]*) *="([^"]*)" *(.*)\', $opts, $parts)) {
				$myopts[$parts[1]] = $parts[2];
				$opts = $parts[3];
			}
			
			$mytext = "<ul class=\"toc\">";
			$TOCList = & new ItemList($blog, array(), "", "", -1, $myopts["category"], array(), "", "DESC", "", $myopts["num"]);
			if (isset($TOCList)) while( $TOCItem = $TOCList->get_item() ) {
				$mytext .= "<li>";
				if ($myopts["dates"] == "true" || $myopts["dates"] == "on") {
					$mytext .= mysql2date( locale_datefmt(), $TOCItem->issue_date, false);
					$mytext .= "<br />";
				}
				$mytext .= "<a href=\"";
				$mytext .= $TOCItem->get_permanent_url();
				$mytext .= "\">"; 
				$mytext .= $TOCItem->title;
				$mytext .= "</a><br/>";
				$content = $TOCItem->content;
				$content = preg_replace("/<!--nextpage-->(\n|.)*/", "", $content);
				$content = preg_replace("/<!--more-->(\n|.)*/", "", $content);
				$post_renderers = $Plugins->validate_list( $TOCItem->get_renderers() );
				$content = $Plugins->render( $content, $post_renderers, "xml", array( "Item" => $TOCItem) );
				$content = format_to_output( $content, "xml" );
				$blah = explode(" ", $content);
				if (count($blah) > $myopts["cut"]) {
					$content="";
					for ($i=0; $i<$myopts["cut"]; $i++)
					{
						$content .= $blah[$i]." ";
					}
					$content .= "...";
				}
				$mytext .= $content;
				$mytext .= "</li>";
			}
			$mytext .= "</ul>";
			return $mytext;'
		),
		$params['data']);
		return true;
	}


	/**
	 * Event handler: Called when displaying the tool menu.
	 *
	 * {@internal toc_plugin::ToolMenu(-)}}
	 *
	 * @param array Associative array of parameters
	 * @return boolean did we display a toolbar?
	 */
	function ToolMenu( $params )
	{
		return false;
	}
}
?>
